@@ -19,7 +19,7 @@ impl BigEndian for Value {
 				&v.to_be_bytes(),
 			]
 			.concat(),
-			F64(v) => [SEP.as_slice(), &v.to_be_bytes()].concat(),
+			U64(v) => [SEP.as_slice(), &v.to_be_bytes()].concat(),
 			Str(v) => [SEP.as_slice(), v.as_bytes()].concat(),
 			_ => unimplemented!(),
 		}
