@@ -16,7 +16,7 @@ pub struct JoinManual {
 
 impl JoinManual {
 	pub fn new(join: AstJoin, context: &Context) -> Result<Self> {
-		let table = Self::table_identity(join.relation)?;
+		let table = join.relation.try_into()?;
 		let (join_type, constraint) = Self::convert_join(join.join_operator)?;
 		let constraint = constraint.simplify_by_context(context)?;
 		Ok(Self {
@@ -26,7 +26,7 @@ impl JoinManual {
 		})
 	}
 	pub fn new_implicit_join(table: TableFactor) -> Result<Self> {
-		let table = Self::table_identity(table)?;
+		let table = table.try_into()?;
 		let (join_type, constraint) = (JoinType::CrossJoin, MetaRecipe::TRUE);
 		Ok(Self {
 			table,
@@ -50,27 +50,4 @@ impl JoinManual {
 		};
 		Ok((join_type, constraint))
 	}
-	pub fn table_identity(table: TableFactor) -> Result<ComplexTableName> {
-		match table {
-			TableFactor::Table { name, alias, .. } => {
-				let name_parts = name.0.len();
-				if !(1..=2).contains(&name_parts) {
-					return Err(JoinError::UnimplementedNumberOfComponents.into());
-				}
-				let database = if name_parts == 2 {
-					name.0.get(0).unwrap().value.clone()
-				} else {
-					String::new()
-				};
-				let name = name.0.last().unwrap().value.clone();
-				let alias = alias.map(|alias| alias.name.value);
-				Ok(ComplexTableName {
-					database,
-					name,
-					alias,
-				})
-			}
-			_ => Err(JoinError::UnimplementedTableType.into()),
-		}
-	}
 }
