@@ -6,14 +6,14 @@ use {
 			types::{ColumnInfo, ComplexTableName},
 			MetaRecipe,
 		},
-		Context, JoinError, Result, StorageInner,
+		Glue, Result,
 	},
 	std::cmp::Ordering,
 };
 
 #[derive(Debug)]
 pub struct JoinPlan {
-	pub database: String,
+	pub database: Option<String>,
 	pub table: String,
 	pub columns: Vec<ColumnInfo>,
 	pub join_type: JoinType,
@@ -38,17 +38,13 @@ impl Ord for JoinPlan {
 }
 
 impl JoinPlan {
-	pub async fn new<'a>(
-		join_manual: JoinManual,
-		storages: &[(String, &mut StorageInner)],
-		context: &Context,
-	) -> Result<Self> {
+	pub async fn new<'a>(join_manual: JoinManual, glue: &Glue) -> Result<Self> {
 		let JoinManual {
 			table,
 			constraint,
 			join_type,
 		} = join_manual;
-		let columns = get_columns(storages, table.clone(), context).await?;
+		let columns = get_columns(glue, table.clone()).await?;
 		let ComplexTableName {
 			database,
 			name: table,
@@ -89,12 +85,8 @@ impl JoinPlan {
 	}
 }
 
-async fn get_columns(
-	storages: &[(String, &mut StorageInner)],
-	table: ComplexTableName,
-	context: &Context,
-) -> Result<Vec<ColumnInfo>> {
-	if let Some((context_table_labels, ..)) = context.tables.get(&table.name) {
+async fn get_columns(glue: &Glue, table: ComplexTableName) -> Result<Vec<ColumnInfo>> {
+	if let Some((context_table_labels, ..)) = glue.get_context()?.tables.get(&table.name) {
 		Ok(context_table_labels
 			.iter()
 			.map(|name| ColumnInfo {
@@ -104,18 +96,6 @@ async fn get_columns(
 			})
 			.collect::<Vec<ColumnInfo>>())
 	} else {
-		let storage = storages
-			.iter()
-			.find_map(|(name, storage)| {
-				if name == &table.database {
-					Some(&**storage)
-				} else {
-					None
-				}
-			})
-			.or_else(|| storages.get(0).map(|(_, storage)| &**storage))
-			.ok_or_else(|| JoinError::TableNotFound(table.clone()))?;
-
-		fetch_columns(storage, table).await
+		fetch_columns(&**glue.get_database(&table.database)?, table).await
 	}
 }
