@@ -3,13 +3,12 @@ use std::sync::Mutex;
 use crate::ExecuteError;
 use {
 	crate::{
-		parse, parse_single, CSVSettings, Connection, Payload, Query, Result, Storage, Value,
+		parse, parse_single, CSVSettings, Connection, Database, Payload, Query, Result, Value,
 		WIPError,
 	},
 	futures::executor::block_on,
 	sqlparser::ast::{
-		Expr, Ident, ObjectName, ObjectType, Query as AstQuery, SetExpr, Statement,
-		Value as AstValue, Values,
+		Expr, Ident, ObjectName, Query as AstQuery, SetExpr, Statement, Value as AstValue, Values,
 	},
 	std::{collections::HashMap, fmt::Debug},
 };
@@ -50,21 +49,21 @@ impl Context {
 /// - [`Glue::select_as_json()`] -- Provides data, only for `SELECT` queries, as one big [String]; generally useful for webby interactions.
 pub struct Glue {
 	pub primary: String,
-	databases: HashMap<String, Storage>,
+	databases: HashMap<String, Database>,
 	context: Mutex<Context>,
 }
 
 /// ## Creation of new interfaces
 impl Glue {
-	/// Creates a [Glue] instance with just one [Storage].
-	pub fn new(name: String, database: Storage) -> Self {
+	/// Creates a [Glue] instance with just one [Database].
+	pub fn new(name: String, database: Database) -> Self {
 		let mut databases = HashMap::new();
 		databases.insert(name, database);
 		Self::new_multi(databases)
 	}
 	/// Creates a [Glue] instance with access to all provided storages.
-	/// Argument is: [Vec]<(Identifier, [Storage])>
-	pub fn new_multi(databases: HashMap<String, Storage>) -> Self {
+	/// Argument is: [Vec]<(Identifier, [Database])>
+	pub fn new_multi(databases: HashMap<String, Database>) -> Self {
 		let context = Mutex::new(Context::default());
 		let primary = databases.keys().next().cloned().unwrap_or_default();
 		Self {
@@ -86,10 +85,10 @@ impl Glue {
 	/// Merge existing [Glue] with [Vec] of other [Glue]s
 	/// For example:
 	/// ```
-	/// use multisql::{SledStorage, Storage, Glue};
-	/// let storage = SledStorage::new("data/example_location/example")
-	///   .map(Storage::new_sled)
-	///   .expect("Storage Creation Failed");
+	/// use multisql::{SledDatabase, Database, Glue};
+	/// let storage = SledDatabase::new("data/example_location/example")
+	///   .map(Database::new_sled)
+	///   .expect("Database Creation Failed");
 	/// let mut glue = Glue::new(String::from("main"), storage);
 	///
 	/// glue.execute_many("
@@ -99,15 +98,15 @@ impl Glue {
 	///   SELECT * FROM test WHERE id > 1;
 	/// ");
 	///
-	/// let other_storage = SledStorage::new("data/example_location/example_other")
-	///   .map(Storage::new_sled)
-	///   .expect("Storage Creation Failed");
+	/// let other_storage = SledDatabase::new("data/example_location/example_other")
+	///   .map(Database::new_sled)
+	///   .expect("Database Creation Failed");
 	/// let mut other_glue = Glue::new(String::from("other"), other_storage);
 	///
-	/// glue.extend(vec![other_glue]);
+	/// glue.extend_many_glues(vec![other_glue]);
 	/// ```
 	///
-	pub fn extend(&mut self, glues: Vec<Glue>) {
+	pub fn extend_many_glues(&mut self, glues: Vec<Glue>) {
 		self.databases.extend(
 			glues
 				.into_iter()
@@ -119,6 +118,53 @@ impl Glue {
 				.databases,
 		)
 	}
+	pub fn extend_glue(&mut self, glue: Glue) {
+		self.databases.extend(glue.databases)
+	}
+
+	/// Extend using a ~~[Path]~~ [String] which represents a path
+	/// Guesses the type of database based on the extension
+	/// Returns [bool] of whether action was taken
+	pub fn try_extend_from_path(
+		&mut self,
+		database_name: String,
+		database_path: String,
+	) -> Result<bool> {
+		if self.databases.contains_key(&database_name) {
+			return Ok(false);
+		}
+		let connection = if database_path.ends_with('/') {
+			Connection::Sled(database_path)
+		} else if database_path.ends_with(".csv") {
+			Connection::CSV(database_path, CSVSettings::default())
+		} else if database_path.ends_with(".xlsx") {
+			Connection::Sheet(database_path)
+		} else {
+			return Err(ExecuteError::InvalidDatabaseLocation.into());
+		};
+		let database = connection.try_into()?;
+		Ok(self.extend(database_name, database))
+	}
+
+	/// Extend [Glue] by single database
+	/// Returns [bool] of whether action was taken
+	pub fn extend(&mut self, database_name: String, database: Database) -> bool {
+		let database_present = self.databases.contains_key(&database_name);
+		if !database_present {
+			self.databases.insert(database_name, database);
+		}
+		!database_present
+	}
+
+	/// Opposite of [Glue::extend], removes database
+	/// Returns [bool] of whether action was taken
+	pub fn reduce(&mut self, database_name: &String) -> bool {
+		let database_present = self.databases.contains_key(database_name);
+		if database_present {
+			self.databases.remove(database_name);
+		}
+		database_present
+	}
 }
 
 /// Internal: Modify
@@ -165,75 +211,6 @@ impl Glue {
 	}
 	/// Will execute a pre-parsed query (see [Glue::pre_parse()] for more).
 	pub fn execute_parsed(&mut self, query: Query) -> Result<Payload> {
-		if let Query(Statement::CreateDatabase {
-			db_name,
-			if_not_exists,
-			location,
-			..
-		}) = query
-		{
-			let store_name = db_name.0[0].value.clone();
-			return if self.databases.iter().any(|(store, _)| store == &store_name) {
-				if if_not_exists {
-					Ok(Payload::Success)
-				} else {
-					Err(ExecuteError::DatabaseExists(store_name).into())
-				}
-			} else {
-				match location {
-					None => Err(ExecuteError::InvalidDatabaseLocation.into()), // TODO: Memory
-					Some(location) => {
-						let store = if location.ends_with('/') {
-							Connection::Sled(location).try_into()?
-						} else if location.ends_with(".csv") {
-							Connection::CSV(location, CSVSettings::default()).try_into()?
-						} else if location.ends_with(".xlsx") {
-							Connection::Sheet(location).try_into()?
-						} else {
-							return Err(ExecuteError::InvalidDatabaseLocation.into());
-						};
-						self.extend(vec![Glue::new(store_name, store)]);
-						Ok(Payload::Success)
-					}
-				}
-			};
-		} else if let Query(Statement::Execute { name, parameters }) = query {
-			return match name.value.as_str() {
-				"FILE" => {
-					if let Some(Ok(query)) = parameters.get(0).map(|path| {
-						if let Expr::Value(AstValue::SingleQuotedString(path)) = path {
-							std::fs::read_to_string(path).map_err(|_| ())
-						} else {
-							Err(())
-						}
-					}) {
-						self.execute(&query)
-					} else {
-						Err(ExecuteError::InvalidFileLocation.into())
-					}
-				}
-				_ => Err(ExecuteError::Unimplemented.into()),
-			};
-		} else if let Query(Statement::Drop {
-			object_type: ObjectType::Schema, // FOR NOW! // TODO: sqlparser-rs#454
-			if_exists,
-			names,
-			..
-		}) = query
-		{
-			let database_name = names
-				.get(0)
-				.and_then(|name| name.0.get(0).map(|name| name.value.clone()))
-				.ok_or(ExecuteError::ObjectNotRecognised)?;
-
-			if self.databases.contains_key(&database_name) {
-				self.databases.remove(&database_name);
-			} else if !if_exists {
-				return Err(ExecuteError::ObjectNotRecognised.into());
-			}
-			return Ok(Payload::Success);
-		}
-
 		block_on(self.execute_query(&query))
 	}
 	/// Provides a parsed query to execute later.
