@@ -1,16 +1,18 @@
-#![allow(clippy::fn_address_comparisons)]
-
 //! # MultiSQL
 //!
 //! `multisql` is a highly modular SQL database engine library written in Rust.
 //! It enables flexible querying via Rust interfaces.
 //!
+//! ## SQL Documentation
+//!
+//! You can find our SQL documentation at [multisql.org](https://multisql.org).
+//!
 //! ## Examples
 //!
 //! ```
-//! use multisql::{SledStorage, Storage, Glue};
-//! let storage = SledStorage::new("data/example_location/lib_example")
-//!   .map(Storage::new_sled)
+//! use multisql::{Connection, Glue};
+//! let storage = Connection::Sled(String::from("data/example_location/lib_example"))
+//!   .try_into()
 //!   .expect("Storage Creation Failed");
 //! let mut glue = Glue::new(String::from("main"), storage);
 //!
@@ -28,17 +30,15 @@
 //! - [SledStorage] -- Most common type of storage/backend
 //! - [Value] -- Value wrapper
 
-pub use sqlparser as parser;
-
 mod data;
+mod database;
+mod databases;
 mod executor;
 mod glue;
 mod parse_sql;
 mod result;
-mod storages;
-mod store;
 mod utils;
 
-pub use {data::*, executor::*, glue::*, parse_sql::*, result::*, storages::*, store::*};
+pub use {data::*, database::*, databases::*, executor::*, glue::*, parse_sql::*, result::*};
 
-pub(crate) use utils::macros;
+pub(crate) use utils::*;
